// $Id: sparse.hpp 3757 2015-11-30 12:03:07Z bradbell $
# ifndef CPPAD_SPARSE_HPP
# define CPPAD_SPARSE_HPP

/* --------------------------------------------------------------------------
CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-15 Bradley M. Bell

CppAD is distributed under multiple licenses. This distribution is under
the terms of the
                    GNU General Public License Version 3.

A copy of this license is included in the COPYING file of this distribution.
Please visit http://www.coin-or.org/CppAD/ for information on other licenses.
-------------------------------------------------------------------------- */

/*
$begin Sparse$$
$spell
$$


$section Calculating Sparsity Patterns$$

$childtable%
	cppad/local/for_sparse_jac.hpp%
	cppad/local/rev_sparse_jac.hpp%
	example/dependency.cpp%
	cppad/local/rev_sparse_hes.hpp%
	example/bool_sparsity.cpp
%$$

$end
*/

# include <cppad/local/for_sparse_jac.hpp>
# include <cppad/local/rev_sparse_jac.hpp>
# include <cppad/local/rev_sparse_hes.hpp>

# endif
